@@ -11,8 +11,6 @@
 /// Include <glm/gtx/string_cast.hpp> to use the features of this extension.
 ///
 /// Setup strings for GLM type values
-///
-/// This extension is not supported with CUDA
 
 #pragma once
 
@@ -23,17 +21,12 @@
 #include "../gtx/dual_quaternion.hpp"
 #include <string>
 #include <cmath>
+#include <cstring>
 
-#if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
-#	ifndef GLM_ENABLE_EXPERIMENTAL
-#		pragma message("GLM: GLM_GTX_string_cast is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it.")
-#	else
-#		pragma message("GLM: GLM_GTX_string_cast extension included")
-#	endif
-#endif
-
-#if(GLM_COMPILER & GLM_COMPILER_CUDA)
-#	error "GLM_GTX_string_cast is not supported on CUDA compiler"
+#ifndef GLM_ENABLE_EXPERIMENTAL
+#	error "GLM: GLM_GTX_string_cast is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it."
+#elif GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
+#	pragma message("GLM: GLM_GTX_string_cast extension included")
 #endif
 
 namespace glm
